@@ -92,7 +92,7 @@ AboutData::AboutData()
                  QLatin1String(kleopatra_version), i18n(description), KAboutLicense::GPL,
                  i18n("(c) 2002 Steffen\u00A0Hansen, Matthias\u00A0Kalle\u00A0" "Dalheimer, Klar\u00E4lvdalens\u00A0" "Datakonsult\u00A0" "AB\n"
                       "(c) 2004, 2007, 2008, 2009 Marc\u00A0Mutz, Klar\u00E4lvdalens\u00A0" "Datakonsult\u00A0" "AB") +
-                 "\n" + i18n("(c) 2010-2017 The Kleopatra developers")
+                 '\n' + i18n("(c) 2010-2017 The Kleopatra developers")
 #ifdef Q_OS_WIN
                  , i18n("<a href=https://www.gpg4win.org>Visit the Gpg4win homepage</a>")
 #endif
@@ -100,10 +100,12 @@ AboutData::AboutData()
 {
     using ::authors;
     using ::credits;
-    for (unsigned int i = 0; i < sizeof authors / sizeof * authors; ++i)
+    for (unsigned int i = 0; i < sizeof authors / sizeof * authors; ++i) {
         addAuthor(i18n(authors[i].name), i18n(authors[i].desc),
                   QLatin1String(authors[i].email), QLatin1String(authors[i].web));
-    for (unsigned int i = 0; i < sizeof credits / sizeof * credits; ++i)
+    }
+    for (unsigned int i = 0; i < sizeof credits / sizeof * credits; ++i) {
         addCredit(i18n(credits[i].name), i18n(credits[i].desc),
                   QLatin1String(credits[i].email), QLatin1String(credits[i].web));
+    }
 }
