@@ -127,12 +127,12 @@ void GenRevokeCommand::doStart()
     while (mOutputFileName.isEmpty()) {
         mOutputFileName = QFileDialog::getSaveFileName(d->parentWidgetOrView(), i18n("Generate revocation certificate"),
                                                        QString(),
-                                                       QStringLiteral("Revocation Certificates (*.rev)"));
+                                                       QStringLiteral("%1 (*.rev)").arg(i18n("Revocation Certificates ")));
         if (mOutputFileName.isEmpty()) {
             d->finished();
             return;
         }
-        if (!mOutputFileName.endsWith(".rev")) {
+        if (!mOutputFileName.endsWith(QLatin1String(".rev"))) {
             mOutputFileName += ".rev";
         }
         if (QFileInfo(mOutputFileName).exists()) {
