@@ -32,9 +32,9 @@
 
 #include <config-kleopatra.h>
 
+#include "keytocardcommand.h"
 #include "kleopatra_debug.h"
 
-#include "keytocardcommand.h"
 #include "command_p.h"
 
 #include "smartcard/readerstatus.h"
@@ -150,7 +150,7 @@ private:
             }
         }
         if (!cardFound) {
-            error(i18n("Failed to find the card with the serial number: %1").arg(mSerial.c_str()));
+            error(i18n("Failed to find the card with the serial number: %1", mSerial.c_str()));
             finished();
             return;
         }
@@ -211,7 +211,7 @@ void KeyToCardCommand::keyToCardDone(const GpgME::Error &err)
         if (KMessageBox::questionYesNo(d->parentWidgetOrView(),
                                        i18n("Do you want to delete the key on this computer?"),
                                        i18nc("@title:window",
-                                       "Key transfered to card")) == KMessageBox::Yes) {
+                                       "Key transferred to card")) == KMessageBox::Yes) {
             const QString cmd = QStringLiteral("DELETE_KEY --force %1").arg(d->mKey.keyGrip());
             // Using readerstatus is a bit overkill but it's an easy way to talk to the agent.
             ReaderStatus::mutableInstance()->startSimpleTransaction(cmd.toUtf8(), this, "deleteDone");
