@@ -62,7 +62,7 @@ using namespace Kleo::Commands;
 using namespace Kleo::Dialogs;
 
 static const char *const components[] = {
-    0, // gpgconf
+    nullptr, // gpgconf
     "gpg",
     "gpg-agent",
     "scdaemon",
@@ -276,7 +276,7 @@ void SelfTestCommand::doCancel()
     if (d->dialog) {
         d->dialog->close();
     }
-    d->dialog = 0;
+    d->dialog = nullptr;
 }
 
 #undef d
