@@ -34,9 +34,8 @@
 
 #include <config-kleopatra.h>
 
-#include "kleopatra_debug.h"
-
 #include "cryptooperationsconfigwidget.h"
+#include "kleopatra_debug.h"
 
 #include "emailoperationspreferences.h"
 #include "fileoperationspreferences.h"
@@ -58,7 +57,6 @@
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDir>
-#include <QLayout>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QPushButton>
@@ -117,7 +115,7 @@ void CryptoOperationsConfigWidget::applyProfile(const QString &profile)
 {
     qCDebug(KLEOPATRA_LOG) << "Applying profile " << profile;
 
-    if (profile == "default") {
+    if (profile == i18n("default")) {
         if (KMessageBox::warningYesNo(
                           this,
                           i18n("This means that every configuration option of the GnuPG System will be reset to its default."),
@@ -141,7 +139,7 @@ void CryptoOperationsConfigWidget::applyProfile(const QString &profile)
     gpgconf->setArguments(QStringList() << QStringLiteral("--apply-profile") << path.toLocal8Bit());
 
     connect(gpgconf, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
-            this, [this, gpgconf] () {
+            this, [this, gpgconf, profile] () {
         if (gpgconf->exitStatus() != QProcess::NormalExit) {
             KMessageBox::error(this, QStringLiteral("<pre>%1</pre>").arg(QString::fromLocal8Bit(gpgconf->readAll())));
             delete gpgconf;
@@ -149,8 +147,9 @@ void CryptoOperationsConfigWidget::applyProfile(const QString &profile)
         }
         delete gpgconf;
         KMessageBox::information(this,
-                         i18nc("@info", "The configuration profile is now applied."),
-                         i18n("Configuration profile applied"));
+                         i18nc("%1 is the name of the profile",
+                               "The configuration profile \"%1\" was applied.", profile),
+                         i18n("GnuPG Profile - Kleopatra"));
         auto config = QGpgME::cryptoConfig();
         if (config) {
             config->clear();
@@ -196,12 +195,12 @@ void CryptoOperationsConfigWidget::setupProfileGui(QBoxLayout *layout)
 
     // We don't translate "default" here because the other profile names are
     // also not translated as they are taken directly from file.
-    combo->addItem(QStringLiteral("default"));
+    combo->addItem(i18n("default"));
     for (const auto &profile: profiles) {
         combo->addItem(profile.baseName());
     }
 
-    auto btn = new QPushButton("Apply");
+    auto btn = new QPushButton(i18n("Apply"));
 
     profLayout->addWidget(profLabel);
     profLayout->addWidget(combo);
@@ -215,7 +214,7 @@ void CryptoOperationsConfigWidget::setupProfileGui(QBoxLayout *layout)
 
 void CryptoOperationsConfigWidget::setupGui()
 {
-    QVBoxLayout *baseLay = new QVBoxLayout;
+    QVBoxLayout *baseLay = new QVBoxLayout(this);
     baseLay->setMargin(0);
 
     QGroupBox *mailGrp = new QGroupBox(i18n("EMail Operations"));
@@ -258,7 +257,6 @@ void CryptoOperationsConfigWidget::setupGui()
 
     baseLay->addStretch(1);
 
-    setLayout(baseLay);
 
     if (!GpgME::hasFeature(0, GpgME::BinaryAndFineGrainedIdentify)) {
         /* Auto handling requires a working identify in GpgME.
@@ -373,4 +371,3 @@ void CryptoOperationsConfigWidget::save()
     }
     filePrefs.save();
 }
-
