@@ -610,7 +610,7 @@ static QString process(const Dir &dir, bool *fatal)
     QTemporaryFile out;
     QProcess p;
     if (!out.open()) {
-        return QStringLiteral("Faile to open Temporary file.");
+        return QStringLiteral("Failed to open Temporary file.");
     }
     p.setWorkingDirectory(dir.dir.absolutePath());
     p.setStandardOutputFile(out.fileName());
@@ -632,8 +632,7 @@ static QString process(const Dir &dir, bool *fatal)
     }
 
     QFileInfo fi(absFilePath);
-    if (!(fi.exists() && !QFile::remove(absFilePath)) && QFile::rename(out.fileName(), absFilePath)) {
-        out.setAutoRemove(false);
+    if (!(fi.exists() && !QFile::remove(absFilePath)) && QFile::copy(out.fileName(), absFilePath)) {
         return QString();
     }
 
