@@ -300,10 +300,10 @@ static QString formatSigningInformation(const Signature &sig)
         text +=
             (QStringLiteral("<br/>")
              + (IS_DE_VS(sig)
-                ? i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a signature is compliant with that.",
-                        "The signature is VS-compliant.")
-                : i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a signature is not compliant with that.",
-                        "The signature <b>is not</b> VS-compliant.")));
+                ? i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a signature is compliant with that.",
+                        "The signature is VS-NfD-compliant.")
+                : i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a signature is not compliant with that.",
+                        "The signature <b>is not</b> VS-NfD-compliant.")));
     }
 
     return text;
@@ -492,7 +492,11 @@ static QString formatSignature(const Signature &sig, const DecryptVerifyResult::
 
     // Red
     if ((sig.summary() & Signature::Red)) {
-        return text + i18n("The signature is invalid: %1", signatureSummaryToString(sig.summary()));
+        const QString ret = text + i18n("The signature is invalid: %1", signatureSummaryToString(sig.summary()));
+        if (sig.summary() & Signature::SysError) {
+            return ret + QStringLiteral(" (%1)").arg(QString::fromLocal8Bit(sig.status().asString()));
+        }
+        return ret;
     }
 
     // Key missing
@@ -509,7 +513,11 @@ static QString formatSignature(const Signature &sig, const DecryptVerifyResult::
     }
 
     // Catch all fall through
-    return text + i18n("The signature is invalid: %1", signatureSummaryToString(sig.summary()));
+    const QString ret = text + i18n("The signature is invalid: %1", signatureSummaryToString(sig.summary()));
+    if (sig.summary() & Signature::SysError) {
+        return ret + QStringLiteral(" (%1)").arg(QString::fromLocal8Bit(sig.status().asString()));
+    }
+    return ret;
 }
 
 static QStringList format(const std::vector<Mailbox> &mbxs)
@@ -551,10 +559,10 @@ static QString formatDecryptionResultDetails(const DecryptionResult &res, const
 
     if (Kleo::gpgComplianceP("de-vs")) {
         details += ((IS_DE_VS(res)
-                     ? i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that the decryption is compliant with that.",
-                             "The decryption is VS-compliant.")
-                     : i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that the decryption is compliant with that.",
-                             "The decryption <b>is not</b> VS-compliant."))
+                     ? i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that the decryption is compliant with that.",
+                             "The decryption is VS-NfD-compliant.")
+                     : i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that the decryption is compliant with that.",
+                             "The decryption <b>is not</b> VS-NfD-compliant."))
                     + QStringLiteral("<br/>"));
     }
 
