@@ -40,6 +40,7 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KColorScheme>
 #include <KConfigGroup>
 
 #include <KMessageBox>
@@ -55,7 +56,6 @@
 #include <QIcon>
 #include <QCheckBox>
 
-#include <QPointer>
 
 #include <gpgme++/key.h>
 
@@ -92,7 +92,6 @@ public:
                 &SigEncPage::updateCommitButton);
         connect(mWidget, &SignEncryptWidget::keysChanged, this,
                 &SigEncPage::updateFileWidgets);
-        setLayout(vLay);
         updateCommitButton(mWidget->currentOp());
 
         auto outputGrp = new QGroupBox(i18n("Output"));
@@ -293,14 +292,14 @@ private Q_SLOTS:
                 btn->setIcon(QIcon::fromTheme(de_vs
                                              ? "security-high"
                                              : "security-medium"));
-                btn->setStyleSheet(de_vs
-                                   ? "background-color: lime"
-                                   : "background-color: red");
+                btn->setStyleSheet(QStringLiteral("background-color: ") + (de_vs
+                                   ? KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color().name()
+                                   : KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color().name()));
                 mParent->setLabelText(de_vs
-                                      ? i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
-                                              "VS-compliant communication possible.")
-                                      : i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
-                                              "VS-compliant communication not possible."));
+                                      ? i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
+                                              "VS-NfD-compliant communication possible.")
+                                      : i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
+                                              "VS-NfD-compliant communication not possible."));
             }
         } else {
             btn->setText(i18n("Next"));
@@ -385,7 +384,7 @@ SignEncryptFilesWizard::SignEncryptFilesWizard(QWidget *parent, Qt::WindowFlags
 {
     bool de_vs = Kleo::gpgComplianceP("de-vs");
 #ifdef Q_OS_WIN
-    // Enforce modern style to avoid vista style uglyness.
+    // Enforce modern style to avoid vista style ugliness.
     setWizardStyle(QWizard::ModernStyle);
 #endif
     mSigEncPage = new SigEncPage(this);
