@@ -35,7 +35,6 @@
 #include <gpgme++/key.h>
 #include <gpgme++/tofuinfo.h>
 
-#include <QStandardItemModel>
 #include <QToolTip>
 #include <QDateTime>
 #include <QDialogButtonBox>
@@ -357,6 +356,7 @@ void CertificateDetailsWidget::Private::setupSMIMEProperties()
         owner = i18nc("<name> of <company>", "%1 of %2", name, o);
     }
     ui.smimeOwner->setText(QStringLiteral("<a href=\"#ownerDetails\">%1</a>").arg(owner));
+    ui.smimeOwner->setContextMenuPolicy(Qt::NoContextMenu);
 
     const Kleo::DN issuerDN(key.issuerName());
     const QString issuerCN = issuerDN[QStringLiteral("CN")];
