@@ -57,8 +57,6 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
