@@ -58,6 +58,8 @@
 
 #include <KXMLGUIFactory>
 #include <QApplication>
+#include <QLineEdit>
+#include <KActionMenu>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -67,21 +69,18 @@
 #include <KStandardGuiItem>
 #include <KShortcutsDialog>
 #include <KEditToolBar>
-#include <KAboutApplicationDialog>
 #include "kleopatra_debug.h"
-#include <QLineEdit>
-#include <KActionMenu>
 #include <KConfigGroup>
 
 #include <QAbstractItemView>
-#include <QApplication>
 #include <QCloseEvent>
 #include <QMenu>
 #include <QTimer>
 #include <QProcess>
 #include <QVBoxLayout>
 #include <QMimeData>
-#include <QDesktopWidget>
+#include <QDesktopServices>
+#include <QDir>
 #include <QStatusBar>
 #include <QLabel>
 
@@ -193,7 +192,8 @@ public:
             auto statusBar = new QStatusBar;
             q->setStatusBar(statusBar);
             auto statusLbl = new QLabel(i18nc("Compliance means that GnuPG is running in a more restricted mode e.g. to handle restricted documents.",
-                                        "Compliance: %1", complianceMode));
+                                        // The germans want some extra sausage
+                                        "Compliance: %1", complianceMode == QStringLiteral("de-vs") ? QStringLiteral ("VS-NfD") : complianceMode));
             statusBar->insertPermanentWidget(0, statusLbl);
 
         } else {
@@ -222,6 +222,19 @@ public:
         UpdateNotification::checkUpdate(q, true);
     }
 
+    void openCompendium()
+    {
+        QDir datadir(QCoreApplication::applicationDirPath() + QStringLiteral("/../share/gpg4win"));
+        const auto path = datadir.filePath(i18nc("The Gpg4win compendium is only available"
+                                                 "at this point (24.7.2017) in german and english."
+                                                 "Please check with Gpg4win before translating this filename.",
+                                                 "gpg4win-compendium-en.pdf"));
+        qCDebug(KLEOPATRA_LOG) << "Opening Compendium at:" << path;
+        // The compendium is always installed. So this should work. Otherwise
+        // we have debug output.
+        QDesktopServices::openUrl(QUrl::fromLocalFile(path));
+    }
+
     void slotConfigCommitted();
     void slotContextMenuRequested(QAbstractItemView *, const QPoint &p)
     {
@@ -385,6 +398,10 @@ void MainWindow::Private::setupActions()
             "help_check_updates", i18n("Check for updates"), QString(),
             "gpg4win-compact", q, SLOT(forceUpdateCheck()), QString(), false, true
         },
+        {
+            "help_show_compendium", i18n("Gpg4win Compendium"), QString(),
+            "gpg4win-compact", q, SLOT(openCompendium()), QString(), false, true
+        },
 #endif
         // most have been MOVED TO keylistcontroller.cpp
 #if 0
