@@ -219,8 +219,10 @@ standard_homedir(void)
                                 NULL, 0, path) >= 0) {
             char *tmp = malloc(strlen(path) + 6 + 1);
 
-            /* FIXME.  */
-            Q_ASSERT(tmp);
+            if (!tmp) {
+                dir = strdup ("C:\\gnupg");
+                return dir;
+            }
 
             strcpy(tmp, path);
             strcat(tmp, "\\gnupg");
@@ -232,7 +234,7 @@ standard_homedir(void)
                 CreateDirectoryA(dir, NULL);
             }
         } else {
-            dir = "C:\\gnupg";
+            dir = strdup("C:\\gnupg");
         }
     }
     return dir;
@@ -270,7 +272,7 @@ default_homedir(void)
         dir = saved_dir;
     }
     if (!dir || !*dir) {
-        dir = "C:\\gnupg";
+        dir = strdup("C:\\gnupg");
     }
 
     return dir;
