@@ -53,19 +53,19 @@ public:
     bool readWouldBlock() const;
     bool writeWouldBlock() const;
 
-    qint64 bytesAvailable() const Q_DECL_OVERRIDE;
-    qint64 bytesToWrite() const Q_DECL_OVERRIDE;
-    bool canReadLine() const Q_DECL_OVERRIDE;
-    void close() Q_DECL_OVERRIDE;
-    bool isSequential() const Q_DECL_OVERRIDE;
-    bool atEnd() const Q_DECL_OVERRIDE;
+    qint64 bytesAvailable() const override;
+    qint64 bytesToWrite() const override;
+    bool canReadLine() const override;
+    void close() override;
+    bool isSequential() const override;
+    bool atEnd() const override;
 
-    bool waitForBytesWritten(int msecs) Q_DECL_OVERRIDE;
-    bool waitForReadyRead(int msecs) Q_DECL_OVERRIDE;
+    bool waitForBytesWritten(int msecs) override;
+    bool waitForReadyRead(int msecs) override;
 
 protected:
-    qint64 readData(char *data, qint64 maxSize) Q_DECL_OVERRIDE;
-    qint64 writeData(const char *data, qint64 maxSize) Q_DECL_OVERRIDE;
+    qint64 readData(char *data, qint64 maxSize) override;
+    qint64 writeData(const char *data, qint64 maxSize) override;
 
 private:
     using QIODevice::open;
