@@ -30,7 +30,7 @@
     you do not wish to do so, delete this exception statement from
     your version.
 */
-#include "config-kleopatra.h"
+#include <config-kleopatra.h>
 
 #include <QtGlobal>
 
